@@ -114,7 +114,7 @@ class CloudDeployGrpcTransport(CloudDeployTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -733,5 +733,8 @@ class CloudDeployGrpcTransport(CloudDeployTransport):
             )
         return self._stubs["get_config"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("CloudDeployGrpcTransport",)
