@@ -74,6 +74,9 @@ class DeliveryPipeline(proto.Message):
     A ``DeliveryPipeline`` defines a pipeline through which a Skaffold
     configuration can progress.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Optional. Name of the ``DeliveryPipeline``. Format is
@@ -95,8 +98,8 @@ class DeliveryPipeline(proto.Message):
             user and by Google Cloud Deploy. Labels must meet the
             following constraints: Each resource is limited to 64
             labels. Keys must conform to the regexp:
-            [a-zA-Z][a-zA-Z0-9\_-]{0,62} Values must conform to the
-            regexp: [a-zA-Z0-9\_-]{0,63} Both keys and values are
+            ``[a-zA-Z][a-zA-Z0-9_-]{0,62}``. Values must conform to the
+            regexp: ``[a-zA-Z0-9_-]{0,63}``. Both keys and values are
             additionally constrained to be <= 128 bytes in size.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time at which the pipeline was
@@ -107,6 +110,7 @@ class DeliveryPipeline(proto.Message):
         serial_pipeline (google.cloud.deploy_v1.types.SerialPipeline):
             SerialPipeline defines a sequential set of stages for a
             ``DeliveryPipeline``.
+            This field is a member of `oneof`_ ``pipeline``.
         condition (google.cloud.deploy_v1.types.PipelineCondition):
             Output only. Information around the state of
             the Delivery Pipeline.
@@ -453,6 +457,9 @@ class Target(proto.Message):
     A ``Target`` defines a location to which a Skaffold configuration
     can be deployed.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Optional. Name of the ``Target``. Format is
@@ -476,8 +483,8 @@ class Target(proto.Message):
             both the user and by Google Cloud Deploy. Labels must meet
             the following constraints: Each resource is limited to 64
             labels. Keys must conform to the regexp:
-            [a-zA-Z][a-zA-Z0-9\_-]{0,62} Values must conform to the
-            regexp: [a-zA-Z0-9\_-]{0,63} Both keys and values are
+            ``[a-zA-Z][a-zA-Z0-9_-]{0,62}``. Values must conform to the
+            regexp: ``[a-zA-Z0-9_-]{0,63}``. Both keys and values are
             additionally constrained to be <= 128 bytes in size.
         require_approval (bool):
             Optional. Whether or not the ``Target`` requires approval.
@@ -488,6 +495,7 @@ class Target(proto.Message):
             updated.
         gke (google.cloud.deploy_v1.types.GkeCluster):
             Information specifying a GKE Cluster.
+            This field is a member of `oneof`_ ``deployment_target``.
         etag (str):
             Optional. This checksum is computed by the
             server based on the value of other fields, and
@@ -527,14 +535,23 @@ class ExecutionConfig(proto.Message):
     r"""Configuration of the environment to use when calling
     Skaffold.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         usages (Sequence[google.cloud.deploy_v1.types.ExecutionConfig.ExecutionEnvironmentUsage]):
             Required. Usages when this configuration
             should be applied.
         default_pool (google.cloud.deploy_v1.types.DefaultPool):
             Optional. Use default Cloud Build pool.
+            This field is a member of `oneof`_ ``execution_environment``.
         private_pool (google.cloud.deploy_v1.types.PrivatePool):
             Optional. Use private Cloud Build pool.
+            This field is a member of `oneof`_ ``execution_environment``.
     """
 
     class ExecutionEnvironmentUsage(proto.Enum):
@@ -853,8 +870,8 @@ class Release(proto.Message):
             user and by Google Cloud Deploy. Labels must meet the
             following constraints: Each resource is limited to 64
             labels. Keys must conform to the regexp:
-            [a-zA-Z][a-zA-Z0-9\_-]{0,62} Values must conform to the
-            regexp: [a-zA-Z0-9\_-]{0,63} Both keys and values are
+            ``[a-zA-Z][a-zA-Z0-9_-]{0,62}``. Values must conform to the
+            regexp: ``[a-zA-Z0-9_-]{0,63}``. Both keys and values are
             additionally constrained to be <= 128 bytes in size.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time at which the ``Release`` was created.
@@ -988,12 +1005,15 @@ class BuildArtifact(proto.Message):
 class TargetArtifact(proto.Message):
     r"""The artifacts produced by a target render operation.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         artifact_uri (str):
             Output only. URI of a directory containing
             the artifacts. This contains deployment
             configuration used by Skaffold during a rollout,
             and all paths are relative to this location.
+            This field is a member of `oneof`_ ``uri``.
         skaffold_config_path (str):
             Output only. File path of the resolved
             Skaffold configuration relative to the URI.
@@ -1149,8 +1169,8 @@ class Rollout(proto.Message):
             user and by Google Cloud Deploy. Labels must meet the
             following constraints: Each resource is limited to 64
             labels. Keys must conform to the regexp:
-            [a-zA-Z][a-zA-Z0-9\_-]{0,62} Values must conform to the
-            regexp: [a-zA-Z0-9\_-]{0,63} Both keys and values are
+            ``[a-zA-Z][a-zA-Z0-9_-]{0,62}``. Values must conform to the
+            regexp: ``[a-zA-Z0-9_-]{0,63}``. Both keys and values are
             additionally constrained to be <= 128 bytes in size.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time at which the ``Rollout`` was created.
